<?PHP
/**
 * Constains lists for grouping marking positions.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out marking positions.
 */
final class MDConcMarkingPosition implements MDImporterConcordanceListInterface {

    private const MARKING_POSITIONS_VERBOSE = [

        // Center
        "mittig" => "center",
        "Mittig" => "center",
        "mittig auf Schild" => "center",
        "Vorderseite, mittig" => "center",
        "beidseitig mittig" => "center",
        "untere Passpartoutkante, mittig" => "center",
        "vorn am Kasten, mittig, einseitig" => "center",
        "an Gehäuse mittig" => "center",

        // Left
        "Links" => "left",
        "links" => "left",
        "linke Ecke im Aquarell" => "left",
        "linkes, blaues Schleifenband" => "left",
        "linkes, grünes Schleifenband" => "left",
        "linkes Band" => "left",
        "mittig links" => "left",
        "Waagebalken links" => "left",
        "Vorderseite links (Brusthöhe)" => "left",
        "an Skala links und am Gehäuse Fronseite" => "left",

        // Right
        "mittig rechts" => "right",
        "Rechts" => "right",
        "rechts" => "right",
        "rechts neben Bildnis" => "right",
        "Rechter Bildrand" => "right",
        "Balken rechts" => "right",

        // Bottom
        "unten" => "bottom",
        "unter der Zeichnung" => "bottom",
        "unter der Bild" => "bottom",
        "unterer Bildrand" => "bottom",
        "Unterer Bildrand" => "bottom",
        "unterer Bildrand, mittig" => "bottom",
        "Unterkante Bild" => "bottom",
        "Boden, unten" => "bottom",
        "unterer Blattrand" => "bottom",
        "Boden" => "bottom",
        "Boden und Standring" => "bottom",
        "untere Passpartoutkante und untere linke Ecke auf Foto" => "bottom",
        "Unterboden" => "bottom",
        "vs unten" => "bottom",
        "untere Passpartoutkante" => "bottom",
        "unten mittig" => "bottom",
        "Unten mittig" => "bottom",
        "Unten mittig auf Platte" => "bottom",

        // Top
        "oben" => "top",
        "oben mittig" => "top",
        "Oben mittig" => "top",
        "oberer Rand" => "top",
        "oberer Balken" => "top",
        "Flasche und Verschluß" => "top",
        "obere Abdeckung" => "top",
        "Mittig oben" => "top",
        "mittig oben" => "top",

        // Bottom left
        "links unter der Zeichnung" => "bottom_left",
        "links unter der Zeichnung Sinatur" => "bottom_left",
        "links unten Signatur" => "bottom_left",
        "linker, unterer Bildrand" => "bottom_left",
        "linker, unterer Bildrand (über dem Knie)" => "bottom_left",
        "linke, untere Passpartoutkante" => "bottom_left",
        "linke, untere Ecke" => "bottom_left",
        "Links unten" => "bottom_left",
        "Unten links" => "bottom_left",
        "unten links" => "bottom_left",

        // Bottom right
        "im Bild unten rechts" => "bottom_right",
        "rechts unten Signatur" => "bottom_right",
        "unterer Bildrand rechts" => "bottom_right",
        "Bildrand rechts unten" => "bottom_right",
        "Rechts unten" => "bottom_right",
        "Unten rechts" => "bottom_right",
        "unten rechts" => "bottom_right",

        // Top Left
        "linker, oberer Bildrand" => "top_left",
        "oben links auf Malschicht" => "top_left",
        "Links oben" => "top_left",
        "Oben links" => "top_left",
        "oben links" => "top_left",

        // Top Right
        "Oben rechts"  => "top_right",
        "oben rechts"  => "top_right",
        "Rechts oben" => "top_right",
        "Rechte obere Ecke"  => "top_right",
        "vorn, oben, rechts am Gehäuse" => "top_right",

        // Edge
        "Rand" => "edge",
        "linker Rand Pergaminhülle (für Kleinbildfilmstreifen)" => "edge",
        "linker Rand Pergaminhülle (für Diapositive im Mittelformat)" => "edge",
        "linker Rand Kunststoffhülle (für Kleinbildfilmstreifen)" => "edge",
        "Schildkante vorn, innen" => "edge",
        "Schildkante hinten, innen" => "edge",
        "äußerer Rand" => "edge",
        "Auflage für Brief am äußeren Rand" => "edge",
        "äußerer Gefäßrand" => "edge",
        "Tellerrand" => "edge",
        "Fußrand, außen" => "edge",
        "unterer seitlicher Rand" => "edge",
        "oberer Rand, aussen" => "edge",
        "oberer und unterer Rand" => "edge",
        "Passepartout" => "edge",
        "Keilrahmen untere Leiste" => "edge",
        "Keilrahmen unterer Schenkel" => "edge",
        "Keilrahmen, unterer Schenkel" => "edge",
        "Keilrahmen oberer Schenkel" => "edge",
        "Keilrahmen, oberer Schenkel" => "edge",

        // Full Front
        "Front" => "front_front",
        "Frontal" => "front_front",
        "Frontseite" => "front_front",
        "Frontalseite" => "front_front",
        "Stirnseite" => "front_front",
        "Volle Vorderseite" => "front_front",
        "Volle Frontseite" => "front_front",
        "Vorderseite" => "front_front",
        "Forderseite" => "front_front",
        "Vorderseite / Stirn" => "front_front",
        "Vorn" => "front_front",
        "vorn" => "front_front",
        "Vorne" => "front_front",
        "vorne" => "front_front",

        // Rear
        "Leinwandrückseite" => "rear_side",
        "Rückseite" => "rear_side",
        "RS" => "rear_side",
        "rs" => "rear_side",
        "Recto" => "rear_side",
        "Revers" => "rear_side",
        "Reverse" => "rear_side",
        "rs Umschrift" => "rear_side",
        "Rückseite der Leinwand" => "rear_side",
        "Rückseitig auf ovalem Keilrahmen oben links und rechts" => "rear_side",
        "Rückseite Kalender" => "rear_side",
        "Rückseite Keilrahmen" => "rear_side",
        "Rükseite" => "rear_side",
        "Rückseite, unter Doublierung" => "rear_side",

        // rear_bottom
        "Rückseite unten" => "rear_bottom",
        "Rückseite, unten" => "rear_bottom",
        "Rückseite unten mittig" => "rear_bottom",
        "Rückseite, unten mittig" => "rear_bottom",
        "Rückseite mittig unten" => "rear_bottom",
        "Rückseite, mittig unten" => "rear_bottom",

        // rear_bottom_left
        "Rückseite unten links" => "rear_bottom_left",
        "Rückseite, unten links" => "rear_bottom_left",
        "Rückseite links unten" => "rear_bottom_left",
        "Rückseite, links unten" => "rear_bottom_left",
        "Rückseite linke untere Ecke" => "rear_bottom_left",

        // rear_bottom_right
        "Rückseite unten rechts" => "rear_bottom_right",
        "Rückseite, unten rechts" => "rear_bottom_right",
        "Rückseite rechts unten" => "rear_bottom_right",
        "Rückseite, rechts unten" => "rear_bottom_right",
        "Rückseite rechte untere Ecke" => "rear_bottom_right",

        // rear_center
        "Rückseite mittig" => "rear_center",
        "Rückseite, mittig" => "rear_center",
        "Rükseite, mittig" => "rear_center",

        // rear_left
        "Rückseite links" => "rear_left",
        "Rückseite, links" => "rear_left",
        "Rückseite mittig links" => "rear_left",
        "Rückseite, mittig links" => "rear_left",
        "Rückseite links mittig" => "rear_left",
        "Rückseite, links mittig" => "rear_left",

        // rear_right
        "Rückseite rechts" => "rear_right",
        "Rückseite, rechts" => "rear_right",
        "Rückseite mittig rechts" => "rear_right",
        "Rückseite, mittig rechts" => "rear_right",
        "Rückseite rechts mittig" => "rear_right",
        "Rückseite, rechts mittig" => "rear_right",
        "Rückseitig rechts" => "rear_right",
        "Rückseitig, rechts" => "rear_right",
        "Rückseitig mittig rechts" => "rear_right",
        "Rückseitig, mittig rechts" => "rear_right",
        "Rückseitig rechts mittig" => "rear_right",
        "Rückseitig, rechts mittig" => "rear_right",

        // rear_top
        "Rückseite oben" => "rear_top",
        "Rückseite, oben" => "rear_top",
        "Rückseite oben mittig" => "rear_top",
        "Rückseite, oben mittig" => "rear_top",
        "Rückseite mittig oben" => "rear_top",
        "Rückseite, mittig oben" => "rear_top",

        // rear_top_left
        "Rückseite links oben" => "rear_top_left",
        "Rückseite, links oben" => "rear_top_left",
        "Rückseite oben links" => "rear_top_left",
        "Rückseite, oben links" => "rear_top_left",
        "Rückseite linke obere Ecke" => "rear_top_left",

        // rear_top_right
        "Rückseite oben rechts" => "rear_top_right",
        "Rückseite, oben rechts" => "rear_top_right",
        "Rückseite rechts oben" => "rear_top_right",
        "Rückseite, rechts oben" => "rear_top_right",
        "Rückseite rechte obere Ecke" => "rear_top_right",

        // topside
        "Oberseite" => "topside",
        "oberhalb" => "topside",

        // underside
        "Unterseite" => "underside",
        "unterhalb" => "underside",

        // Misc.
        "x" => "other",
        "VS" => "other",
        "VS:" => "other",
        "vs" => "other",
        "vs:" => "other",
        "vs." => "other",
        "VS und RS" => "other",
        "vs: oben/ unten" => "other",
        "VS Fahne" => "other",
        "Balken" => "other",
        "Zugbalken" => "other",
        "innen" => "other",
        "inneres Lederfutter" => "other",
        "Innenseite" => "other",
        "unter Gewichtsauflagenschale" => "other",
        "Standsäule" => "other",
        "Typenschild" => "other",
        "Typenschild Alum" => "other",
        "Typenschild Alum." => "other",
        "Typenschild am Gestell" => "other",
        "Typenschild an Gestellfront" => "other",
        "Tellerunterseite" => "other",
        "Skalenschiene" => "other",
        "Skala" => "other",
        "an Skala" => "other",
        "unter Skala" => "other",
        "an Skala links" => "other",
        "auf Skala" => "other",
        "Vorderseite Eisengestell" => "other",
        "Außenwand" => "other",
        "Aufkleber" => "other",
        "unter Ausgußtülle" => "other",
        "Glasaußenseite" => "other",
        "Tellermitte" => "other",
        "an Gehäuse vorn" => "other",
        "auf Ständersockel und an Balkenmitte beidseitig" => "other",
        "Ständer" => "other",
        "Waagebalken" => "other",
        "vorn an Rahmen, mittig" => "other",
        "Holzbrett" => "other",
        "auf Siegelstempel" => "other",
        "Boden/innen, Boden/außen, 2 x Rand/außen" => "other",
        "Boden/innen, Rand/innen, mittig und Rand/außen" => "other",
        "vorn am Gehäuse" => "other",
        "Boden/innen (sehr groß, ca. 5x5cm) und am Rand/außen (3x)" => "other",
        "Außenrand" => "other",
        "vorn an Fußgestell, mittig, beidseitig" => "other",
        "Messingschild vorn" => "other",
        "inneres Seidenfutter" => "other",
        "auf Pappe" => "other",
        "Bund innen" => "other",
        "Boden, innen" => "other",
        "Deckel" => "other",
        "Boden/innen und am Rand/außen 2x" => "other",
        "Deckeloberseite" => "other",
        "vorn an Gehäuse" => "other",
        "Gestell" => "other",
        "Gestellverstärkung (mittig)" => "other",
        "Mundstück" => "other",
        "Original-Negativhülle" => "other",
        "vorderer Waagbalken" => "other",
        "Waagenbalken, linke Seite" => "other",
        "auf Original-Negativhülle" => "other",
        "V/1786,1/H" => "other",
        "vorn Typenbezeichnung" => "other",
        "langer Waagebalken, seitlich, beidseitig" => "other",
        "Knauf" => "other",
        "Deckel innen" => "other",
        "Anzeigenskala" => "other",
        "Lehne vorn" => "other",
        "Oberseite Holzsohle, mittig im oberer Drittel" => "other",
        "Vorderseite Ziffernblatt" => "other",
        "Boden, außen" => "other",
        "außen" => "other",
        "aussen" => "other",
        "am Gehäuse" => "other",
        "auf Gewichten" => "other",
        "Gewichte" => "other",
        "Vorderseite Kasten" => "other",
        "auf Rundgewicht" => "other",
        "auf oberen Stab" => "other",
        "auf Klinge" => "other",
        "Gabel" => "other",
        "Griff" => "other",
        "Lampenfuß" => "other",
        "Glasrand, außen" => "other",
        "Standfuß" => "other",
        "Boden/innen, mittig und am Rand/außen, übereinander 2x" => "other",
        "Schulterplatte" => "other",
        "Sockel/Platte" => "other",
        "auf Deckel" => "other",
        "unterer Waagebalken" => "other",
        "Rückseite Waage" => "other",
        "Schneide" => "other",
        "Sockel" => "other",
        "mittig auf Bügel" => "other",
        "auf Foto" => "other",
        "mittig auf Rundholz" => "other",
        "Deckel oben" => "other",
        "Außenseite" => "other",
        "mittig 2 mal am Fußgestell" => "other",
        "an allen Skalenenden" => "other",
        "an Skala rechts" => "other",
        "Ständer vorn" => "other",
        "Waagebalken über Hauptschneide" => "other",
        "Gußplatte" => "other",
        "Schild" => "other",
        "Karton außen" => "other",
        "Henkel" => "other",
        "Gehäuse" => "other",
        "an Gehäuse" => "other",
        "auf Gehäuse" => "other",
        "Porzellanumschluß" => "other",
        "Porzellangewichte" => "other",
        "Kopf oben" => "other",
        "Gewicht" => "other",
        "Verschlußkasten, beidseitig" => "other",
        "Oberseite vom Verschlußkasten der Waage, oberhalb der Säule" => "other",
        "Fußrand" => "other",
        "Bodenrand" => "other",
        "Front Schreibmaschine, Schlüssel" => "other",
        "Boden außen" => "other",
        "Deckel, innen" => "other",
        "Bodenrand innen" => "other",
        "Deckelrand" => "other",
        "Boden, mittig" => "other",
        "Unterseite Sockel" => "other",
        "äußere Hülle" => "other",
        "Gehäuse vorn" => "other",
        "über unterer Ofenklappe" => "other",
        "Kasten vorn" => "other",
        "Griff, Vorderseite" => "other",
        "Pfeifenkopf" => "other",
        "Inschrift im großen Bild" => "other",
        "unterhalb der Lithografie" => "other",
        "unterhalb der Fotografie" => "other",
        "rechts unter der Fotografie" => "other",
        "Waagebalken und Fuß" => "other",
        "Verkleidungsfuß" => "other",
        "Zierverkleidung" => "other",
        "vordere Skala" => "other",
        "Fußgestänge" => "other",
        "vorn an Fußgestell, mittig, einseitig, in gold hervorgehoben" => "other",
        "vorn an Fußgestell, mittig, beidseitig und am Waagebalken" => "other",
        "Fahnespitze" => "other",
        "Umschrift" => "other",
        "Gehäuse seitlich" => "other",
        "Skala und schale" => "other",
        "am Rand des Mittelteils" => "other",
        "am Waagebalken" => "other",
        "an Front vom Gehäuse" => "other",
        "Fußgestell" => "other",
        "auf Fuß oben auf" => "other",
        "im Spiegel" => "other",
        "auf Umschlußkasten vorn" => "other",
        "Zeigerende und Schalenbodenrand" => "other",
        "vorn am Porzellankasten, mittig, einseitig" => "other",
        "Kastendeckel außen" => "other",
        "Kragen" => "other",
        "vorn, unter dem Geldschlitz" => "other",
        "Oberseite Kiste" => "other",
        "beidseitig am Waagengestell, Waagebalken, auf Abdeckung" => "other",
        "vs Umschrift" => "other",
        "Vorderseite Akkordeon" => "other",
        "mittig am Fußgestell" => "other",
        "Balkenskala links" => "other",
        "Signatur (gedruckt)" => "other",
        "auf Passpartout" => "other",
        "auf Papp-Schmuckrahmen" => "other",
        "Fotomitte" => "other",
        "Gehäuseboden, innerer Rand" => "other",
        "Flasche" => "other",
        "auf dem Kontaktbogen unter dem jeweiligen Bild" => "other",
        "Waage" => "other",
        "Weiteres" => "other",
        "auf Kunststoffhülle (für Kleinbildfilmstreifen)" => "other",
        "Textplatte" => "other",
        "oberer Holzkasten" => "other",
        "Verso" => "other",
        "Avers" => "other",
        "Text" => "other",
    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::MARKING_POSITIONS_VERBOSE[$input])) {
            throw new MDImporterMissingConcordance("Unknown marking position: " . $input);
        }

        return self::MARKING_POSITIONS_VERBOSE[$input];

    }
}
